import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:common_module/utils/xapp_utils.dart';

class IEmptyStatus extends StatefulWidget {
  // 距离顶部padding
  final double paddingTop;
  // 显示的图标
  final String? icon;
  final double? iconSize;
  // 提示信息
  final String msg;
  // 按钮文字
  final String btnText;
  final Color? btnColor;
  final double? btnRadius;
  // 点击按钮回调，netWorkConnectd 网络是否连接
  final Function(bool netWorkConnectd)? onTap;

  IEmptyStatus(
      {this.paddingTop = 139,
      this.msg = "加载失败,请刷新重试",
      this.btnText = "点击刷新",
      this.btnColor,
      this.btnRadius,
      this.onTap,
      this.iconSize,
      Key? key,
      this.icon})
      : super(key: key);

  @override
  _IEmptyStatusState createState() => _IEmptyStatusState();
}

class _IEmptyStatusState extends State<IEmptyStatus> {
  // 网络是否连接
  bool netWorkConnected = true;

  // 真正显示的icon
  String? get _icon {
    if (!netWorkConnected) {
      return "assets/network_status_icon.png";
    }
    if (widget.icon == null) {
      return 'assets/empty_status_icon.png';
    }
    return widget.icon;
  }

  // 真正显示的提示信息
  String get _msg {
    if (!netWorkConnected) {
      return '网络中断，请检查网络';
    }
    return widget.msg;
  }

  String get _btnText {
    if (!netWorkConnected) {
      return '点击刷新';
    }
    return widget.btnText;
  }

  @override
  void initState() {
    super.initState();
    checkNetWork();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.only(top: widget.paddingTop.rpx),
      child: Column(
        children: <Widget>[
          Image.asset(
            _icon!,
            width: widget.iconSize ?? 261.rpx,
          ),
          Padding(
            padding: EdgeInsets.only(top: 16.rpx, bottom: 30.rpx),
            child: Text(
              _msg,
              style: TextStyle(
                color: Color.fromRGBO(153, 153, 153, 1),
                fontSize: 14.rpx,
              ),
            ),
          ),
          TextButton(
            onPressed: () async {
              if (widget.onTap != null) {
                var connectivityResult =
                    await (new Connectivity().checkConnectivity());
                var netWorkConnected =
                    connectivityResult != ConnectivityResult.none;
                widget.onTap!(netWorkConnected);
              }
            },
            child: ClipRRect(
              borderRadius: BorderRadius.circular(widget.btnRadius ?? 8.rpx),
              child: Container(
                alignment: Alignment.center,
                width: 210.rpx,
                height: 40.rpx,
                color: Color.fromRGBO(255, 202, 0, 1),
                child: Text(
                  _btnText,
                  style: TextStyle(
                      fontSize: 16.rpx, color: widget.btnColor ?? Colors.white),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  // 检查网络
  void checkNetWork() async {
    var connectivityResult = await (new Connectivity().checkConnectivity());
    this.netWorkConnected = connectivityResult != ConnectivityResult.none;
    setState(() {});
  }
}
