import 'package:flutter/services.dart';
import 'package:fluttet_clipboard/fluttet_clipboard.dart';
import 'dart:io';
import './store_utils.dart';

const LOCAL_COPY_TEXT_KEY = "__local_copy_text_key__";

class ClipboardUtils {
  //复制到剪贴板
  static Future<bool> copyText(String text) async {
    //如果是本app内复制的,存起来不识别
    StoreUtils.getInstance()!.setKV(key: LOCAL_COPY_TEXT_KEY, value: text);
    if (Platform.isIOS) {
      await Clipboard.setData(ClipboardData(text: text));
      return true;
    }
    await FluttetClipboard.setText(text);
    return true;
  }

  //获取剪贴板文字
  static Future<String?> getAppClipboardText() async {
    if (Platform.isIOS) {
      var data = await Clipboard.getData(Clipboard.kTextPlain);
      if (data == null) {
        return null;
      }
      return data.text;
    }
    try {
      var data = await FluttetClipboard.getText();
      if (data != null) {
        return data;
      } else {
        return null;
      }
    } catch (e) {
      return null;
    }
  }

  //清除剪贴板文字
  static Future<void> clearAppClipboardText() {
    return ClipboardUtils.copyText("");
  }

  // 获取本地复制的文本
  static String? getLocalCopyText() {
    return StoreUtils.getInstance()!.getForKey(key: LOCAL_COPY_TEXT_KEY,defaultValue:'');
  }
}
