import 'package:config_module/routes/config.dart';
import 'package:common_module/utils/navigate_utils.dart';

const String h5BaseURL = String.fromEnvironment("h5BaseURL",
    defaultValue:
        'https://xmxcdn.xiaomanxiong.net/'); //http://flutterh5.test.xiaomanxiong.cn/

class PageUtils {
  static PageUtils? _instance;

  static PageUtils? getInstance() {
    if (_instance == null) {
      _instance = new PageUtils();
    }
    return _instance;
  }

  /// 打开H5页面
  /// [url] 链接
  /// [title] 标题，不传会自动获取html页面title
  /// [needLogin]    是否需要登录
  /// [showRefresh]  是否显示刷新按钮
  /// [hideTitleBar] 是否隐藏标题栏
  Future openH5({
    required String url,
    String? title,
    dynamic pageParam,
    bool needLogin = true,
    bool needAuth = false,
    bool openNative = false,
    bool hideTitleBar = false,
    int clearCache = 1,
  }) {
    assert(url != null);

    return NavigateUtils.push(
        path: RouterName.H5_PAGE,
        needLogin: needLogin,
        isNative: openNative,
        arguments: {
          "url": url,
          "title": title,
          "clearCache": clearCache,
          "pageParam": pageParam
        });
  }

  /// 打开用户服务协议
  void openAgreementRegister(
      {bool needLogin = false, bool openNative = false}) {
    var url = '$h5BaseURL#/agreement/register';
    // 生产环境走其他域名
    this.openH5(
        url: url, title: "服务协议", needLogin: needLogin, openNative: openNative);
  }

  /// 打开用户隐私协议
  void openAgreementPrivacy({bool needLogin = false, bool openNative = false}) {
    var url = '$h5BaseURL#/agreement/privacy';

    this.openH5(
      url: url,
      title: "隐私政策",
      needLogin: needLogin,
      openNative: openNative,
    );
  }

  /// 打开用户隐私协议
  void openAgreementSDK({bool needLogin = false, bool openNative = false}) {
    var url = '$h5BaseURL#/agreement/sdk';

    this.openH5(
      url: url,
      title: "第三方SDK",
      needLogin: needLogin,
      openNative: openNative,
    );
  }

  /// 打开意见反馈
  void openFAQ() {
    PageUtils.getInstance()!.openH5(
        clearCache: 0,
        url: 'https://wenjuan.feishu.cn/m/cfm?t=sJEKcKXY1Qni-dy5g');
  }

  // 打开饿了么外卖
  void openEleme() {
    var url = '$h5BaseURL#/elm';
    openH5(url: url, title: "饿了么外卖");
  }

  // 打开饿了么外卖
  void openGuideBook() {
    var url = '$h5BaseURL#/guide_book';
    openH5(url: url, title: "新手教程");
  }

  // 打开新人免单
  void openNewPeopleZero() {
    var url = '$h5BaseURL#/new_people_zero';
    openH5(url: url, title: "新人首单0元");
  }
}
