import 'dart:io';
import 'package:umeng_common_sdk/umeng_common_sdk.dart';
import 'package:umeng_crash/umeng_crash.dart';

/// 公司友盟Key
const String _IOS_KEY = "611b2a4c1fee2e303c25b52a";
const String _ANDROID_KEY = "6110f075063bed4d8c112310";

// 友盟
class UmengUtils {
  static void preInit() {
    String appKey = Platform.isIOS ? _IOS_KEY : _ANDROID_KEY;
    UmengCommonSdk.preInit(
      appKey: appKey,
      channel: 'qiaomeng',
      enableLog: true,
    );
  }
  
  static init() {
    String appKey = Platform.isIOS ? _IOS_KEY : _ANDROID_KEY;
    UmengCommonSdk.init(
      appKey: appKey,
      channel: 'qiaomeng',
      deviceType: 1,
      pushSecret: appKey,
      mode: true,
      process: true,
    ).then((value) {
      print("####-友盟初始化-$value");
    });
  }

  // 发送自定义事件（目前属性值支持字符、整数、浮点、长整数，暂不支持NULL、布尔、MAP、数组）
  static void onEvent(String event, Map<String, dynamic> properties) {
    UmengCommonSdk.onEvent(
      event: event,
      properties: properties,
    );
  }

  // 进入页面统计（手动采集时才可设置）
  static void onPageStart(String viewName, dynamic args) {
    //$args
    print('=======*****埋点触发*****in--$viewName=========');
    Map<String, dynamic> _args = Map<String, dynamic>.from(args);
    _args["_event_type_"] = 'page_start';
    String time = DateTime.now().toString();
    _args["_Time_"] = 'startTime:$time';
    UmengCommonSdk.onEvent(
      event: viewName,
      properties: _args,
    );
  }

  // 离开页面统计（手动采集时才可设置）
  static void onPageEnd(String viewName, dynamic args) {
    //$args
    print('=======*****埋点触发*****out--$viewName=========');
    Map<String, dynamic> _args = Map<String, dynamic>.from(args);
    _args["_event_type_"] = 'page_end';
    String time = DateTime.now().toString();
    _args["_Time_"] = 'endTime:$time';
    UmengCommonSdk.onEvent(
      event: viewName,
      properties: _args,
    );
  }

  ///
  /// 自定义异常上报接口 
  /// [e] 异常信息 
  /// [type] 异常类型
  ///
  static void generateCustomLog({required String e,required String type}){
    UmengCrash.generateCustomLog(e: e, type: type);
  }
  
  ///
  /// 程序退出时，用于保存统计数据的API。 如果开发者调用kill或者exit之类的方法杀死进程，或者双击back键会杀死进程，请务必在此之前调用onKillProcess方法，用来保存统计数据。
  ///
  static void onKillProcess(){
    UmengCrash.onKillProcess();
  }
}
