import 'package:cached_network_image/cached_network_image.dart' as Cache;
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class CachedNetworkImage extends StatelessWidget {
  final String imageUrl;
  final Widget Function(BuildContext, String)? placeholder;
  final Widget Function(
          BuildContext context, String url, Cache.DownloadProgress progress)?
      progressIndicatorBuilder;
  final double? width;
  final double? height;
  final BoxFit? fit;
  final Color? color;
  final AlignmentGeometry alignment;
  const CachedNetworkImage(
      {Key? key,
      required this.imageUrl,
      this.placeholder,
      this.progressIndicatorBuilder,
      this.width,
      this.height,
      this.fit,
      this.color,
      this.alignment = Alignment.center})
      : assert(imageUrl != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    var data = MediaQuery.of(context);
    var devicePixelRatio = data.devicePixelRatio;
    return Cache.CachedNetworkImage(
      alignment: alignment as Alignment,
      imageUrl: imageUrl,
      placeholder: placeholder,
      width: width,
      height: height,
      fit: fit,
      fadeInDuration: Duration(milliseconds: 100),
      color: color,
      memCacheHeight:
          getMemCacheSize(size: height, devicePixelRatio: devicePixelRatio),
      memCacheWidth:
          getMemCacheSize(size: width, devicePixelRatio: devicePixelRatio),
      // maxHeightDiskCache:
      //     getDiskCacheSize(size: height, devicePixelRatio: devicePixelRatio),
      // maxWidthDiskCache:
      //     getDiskCacheSize(size: width, devicePixelRatio: devicePixelRatio),
    );
  }

  int? getDiskCacheSize({double? size, double? devicePixelRatio}) {
    if (size == null || size == double.infinity) {
      return null;
    }
    return (size * devicePixelRatio!).toInt();
  }

  int? getMemCacheSize({required double? size, double? devicePixelRatio}) {
    if (size == null || size == double.infinity) {
      return null;
    }
    return (size * devicePixelRatio!).toInt();
  }
}
